import board, time, busio, pwmio, random
from analogio import AnalogIn
from adafruit_apds9960.apds9960 import APDS9960
import displayio
import adafruit_displayio_ssd1306
import terminalio
from adafruit_display_text import label
import adafruit_displayio_ssd1306
from adafruit_motor import servo

displayio.release_displays()
oled_reset = board.GP6
i2c = board.STEMMA_I2C()
display_bus = displayio.I2CDisplay(i2c, device_address=0x3d, reset=oled_reset)

WIDTH = 128
HEIGHT = 32
BORDER = 5

display = adafruit_displayio_ssd1306.SSD1306(display_bus, width=WIDTH, height=HEIGHT)

splash = displayio.Group()
display.show(splash)

color_bitmap = displayio.Bitmap(WIDTH, HEIGHT, 1)
color_palette = displayio.Palette(1)
color_palette[0] = 0xFFFFFF  # White

bg_sprite = displayio.TileGrid(color_bitmap, pixel_shader=color_palette, x=0, y=0)
splash.append(bg_sprite)

# set up a servo on CPB pin A2
pwm1 = pwmio.PWMOut(board.GP15, frequency=50)
pwm2 = pwmio.PWMOut(board.GP16, frequency=50)
pwm3 = pwmio.PWMOut(board.GP17, frequency=50)

potentiometer = AnalogIn(board.GP28)

#i2c2 = busio.I2C(board.GP9, board.GP8)

#i2c = board.STEMMA_I2C()
multi_sensor = APDS9960(i2c)
multi_sensor.enable_proximity = True

#Need to make Reeses top of potentiometer
servo_1 = servo.Servo(pwm1, min_pulse = 650, max_pulse = 2500) #M&M
servo_2 = servo.Servo(pwm2, min_pulse = 650, max_pulse = 2650) #Skittle
servo_3 = servo.Servo(pwm3, min_pulse = 650, max_pulse = 2600) #Reeses

def servo_move(servo):
    servo.angle = 135
    time.sleep(0.15)
    servo.angle = 180
    time.sleep(2.5)
    bg_sprite = displayio.TileGrid(color_bitmap, pixel_shader=color_palette, x=0, y=0)
    splash.append(bg_sprite)

def screen_print(text):
    inner_bitmap = displayio.Bitmap(WIDTH - BORDER * 2, HEIGHT - BORDER * 2, 1)
    inner_palette = displayio.Palette(1)
    inner_palette[0] = 0x000000  # Black
    inner_sprite = displayio.TileGrid(
        inner_bitmap, pixel_shader=inner_palette, x=BORDER, y=BORDER
    )
    splash.append(inner_sprite)

    # Draw a label
    text_area = label.Label(
        terminalio.FONT, text=text, color=0xFFFFFF, x=28, y=HEIGHT // 2 - 1
    )
    splash.append(text_area)
    time.sleep(1.5)

servo_1.angle = 180
servo_2.angle = 180
servo_3.angle = 180
# set angle (range can be from 0 to 180 - this is 180)
while True:
    reading = multi_sensor.proximity
    if reading>10:
        pot_value = potentiometer.value
        if pot_value <= 16384:
            #Make Reeses
            print("Reeses")
            screen_print("Reeses!")
            servo_move(servo_1)
        elif pot_value <= 16384*2:
            #Keep Skittles
            print("Skittle!")
            screen_print("Skittles!!")
            servo_move(servo_2)
        elif pot_value <= 16384*3:
            #Make M&M
            print("M&M")
            screen_print("M&Ms!")
            servo_move(servo_3)
        else:
            num = random.randint(1,3)
            if num ==1:
                print("Reeses")
                screen_print("Reeses!")
                servo_move(servo_1)
            if num == 2:
                print("Skittle!")
                screen_print("Skittles!")
                servo_move(servo_2)
            if num == 3:
                print("M&M")
                screen_print("M&Ms!")
                servo_move(servo_3)

    time.sleep(0.1)
